# FAEyeTON
demo library for CODE-AI-2022 project. Contains pre-build and pre-release version of project code.


video files for analisyng https://drive.google.com/drive/folders/1q1-hidf9jFaUkVxr9sHEhlKVLcE5Y9TL?usp=sharing


programm notation:
class called: ClassName
methods called: method_name
variables called: variableName
arguments called: argument_name

Current class diagram:

![image](https://user-images.githubusercontent.com/45206030/213150470-0f1925be-abd1-4a5b-b14c-fd473baf90fc.png)

Concept model:
![Class Diagram-Страница 11 (2)](https://user-images.githubusercontent.com/45206030/213150957-f4c75221-6ce9-42eb-bc33-f1c9c9bfdcbb.png)


device     : 50%

input      : 90%

analise    : 90%

evaluate   : 25%

emulate    : 5%




